/*  $Id: TestConfigHandler.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.Properties;

import net.eduvax.util.AbstractConfigChecker;
import net.eduvax.util.ConfigChecker;
import net.eduvax.util.ConfigHandler;
import org.junit.*;
import static org.junit.Assert.*;

public class TestConfigHandler {
    @Before public void setUp() {
        Properties defaultProp=new Properties();
        defaultProp.put("p1","p1default");
        defaultProp.put("p2","p2default");
        defaultProp.put("p3","p2default");
        String args[]={"-p3","p3args","-p4","p4args"};
		configHandler=new ConfigHandler(
						defaultProp,
						PROPFILE,
						args,
						null);
		configHandler.load();						
        config=configHandler.get();
    }
    @After public void tearDown() {
    }

    @Test public void testDefault() {
        assertTrue("p1default".equals(config.getProperty("p1")));
        assertFalse("p2default".equals(config.getProperty("p2")));                
        assertFalse("p3default".equals(config.getProperty("p3")));                
        assertNull(config.getProperty("ungrosnimportequoipouretresurquecestnull"));                
    }
    @Test public void testRcFile() {
        assertTrue("p2file".equals(config.getProperty("p2")));                
        assertFalse("p3file".equals(config.getProperty("p3")));                
    }
    @Test public void testArgs() {
        assertTrue("p3args".equals(config.getProperty("p3")));                
        assertTrue("p4args".equals(config.getProperty("p4")));                
    }
	@Test public void testCheck() {
		ConfigChecker ccOK=new AbstractConfigChecker() {
			public int checkProperty(String name,String value) {
				return CC_OK;
			}
		};
		ConfigChecker ccKO=new AbstractConfigChecker() {
			public int checkProperty(String name,String value) {
				return CC_ERR;
			}
		};
		configHandler.setChecker(ccOK);
		assertTrue(ConfigChecker.CC_OK==configHandler.load());
		configHandler.setChecker(ccKO);
		assertTrue(ConfigChecker.CC_ERR==configHandler.load());
	}
	/**
	 * @djin.cr 1-16
	 */
	@Test public void testHomePath() {
		final String rcFile="TestRcFile.properties";
		String testRcFile=System.getProperty("user.home")+"/"+rcFile;
		boolean fileError=true;
		try {
			PrintStream out=new PrintStream(new FileOutputStream(testRcFile));
			out.println("p2=p2home");
			out.close();
			fileError=false;
		}
		catch (Exception ex) {
			ex.printStackTrace();
		}
		assertFalse(fileError);
		configHandler=new ConfigHandler(
						null,
						"~/"+rcFile,
						null,
						null);
		configHandler.load();						
        config=configHandler.get();
        assertTrue("p2home".equals(config.getProperty("p2")));                
	}
	private final static String PROPFILE="src/test/TestConfigHandler.properties";
	private ConfigHandler configHandler; 
    private Properties config;    
}        
