/*  $Id: TestScriptRunner.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import org.junit.*;
import static org.junit.Assert.*;

import java.util.Iterator;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptEngineManager;
import net.eduvax.util.App;
import net.eduvax.util.Error;
import net.eduvax.util.ErrorHandler;
import net.eduvax.util.ScriptRunner;

public class TestScriptRunner implements ErrorHandler {
		private boolean _scriptError;
		@Before public void setUp() {
			App.init();
			_scriptError=false;

//org.python.core.PySystemState engineSys = new org.python.core.PySystemState();
//org.python.core.Py.setSystemState(engineSys);


		}
		@After public void tearDown() {
		}

		@Test public void testListScriptEngines() {
			ScriptEngineManager manager=new ScriptEngineManager();
			Iterator<ScriptEngineFactory> it=
								manager.getEngineFactories().iterator();
			int i=0;
			while (it.hasNext()) {
				i++;
				App.TRACE("script engine "+i+": "+it.next().getEngineName());
			}
		}
		private void doTestScript(String scriptPath) {
			ScriptRunner python=ScriptRunner.getScriptRunner(scriptPath);
			InScriptChecker checker=new InScriptChecker();
			python.exportVar("_checker",checker);
			python.setErrHandler(this);
			assertFalse(checker.isChecked());
			python.run();
			assertTrue(checker.isChecked());
			assertFalse(_scriptError);
		}	
        @Test public void testPythoOK() {
			doTestScript("src/test/script.py");
        }

		@Test public void testJavascriptOK() {
			doTestScript("src/test/script.js");
		}

		public void handle(Error err) {
			_scriptError=true;
			App.TRACE(err.getMessage());
		}
		public boolean checkOnly() {
			return !_scriptError;
		}
		public boolean checkAndReset() {
			boolean res=checkOnly();
			_scriptError=false;
			return res;
		}

		public class InScriptChecker {
			private boolean _checked=false;
			public void check() {
				_checked=true;
			}
			public boolean isChecked() {
				return _checked;
			}
		}
}		
